@@ -6,7 +6,7 @@
  * Copyright (C) 2004-2008
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: testpcsc.c 3069 2008-07-30 14:03:21Z rousseau $
+ * $Id: testpcsc.c 4233 2009-05-28 13:30:12Z rousseau $
  */
 
 /**
@@ -35,8 +35,7 @@
 #define NORMAL "\33[0m"
 #define MAGENTA "\33[35m"
 
-void test_rv(LONG rv, SCARDCONTEXT hContext, int dont_panic);
-void test_rv(LONG rv, SCARDCONTEXT hContext, int dont_panic)
+static void test_rv(LONG rv, SCARDCONTEXT hContext, int dont_panic)
 {
 	if (rv != SCARD_S_SUCCESS)
 	{
@@ -45,15 +44,15 @@ void test_rv(LONG rv, SCARDCONTEXT hContext, int dont_panic)
 		else
 		{
 			printf(RED "%s\n" NORMAL, pcsc_stringify_error(rv));
-			SCardReleaseContext(hContext);
+			(void)SCardReleaseContext(hContext);
 			exit(-1);
 		}
 	}
 	else
-		puts(pcsc_stringify_error(rv));
+		(void)puts(pcsc_stringify_error(rv));
 }
 
-int main(int argc, char **argv)
+int main(/*@unused@*/ int argc, /*@unused@*/ char **argv)
 {
 	SCARDHANDLE hCard;
 	SCARDCONTEXT hContext;
@@ -66,7 +65,11 @@ int main(int argc, char **argv)
 #else
 	unsigned char pbAtr[MAX_ATR_SIZE];
 #endif
-	unsigned char buf[100];
+	union {
+		unsigned char as_char[100];
+		DWORD as_DWORD;
+		uint32_t as_uint32_t;
+	} buf;
 	DWORD dwBufLen;
 	unsigned char *pbAttr = NULL;
 	DWORD pcbAttrLen;
@@ -82,6 +85,9 @@ int main(int argc, char **argv)
 	unsigned char bRecvBuffer[MAX_BUFFER_SIZE];
 	DWORD send_length, length;
 
+	(void)argc;
+	(void)argv;
+
 	printf("\nMUSCLE PC/SC Lite unitary test Program\n\n");
 
 	printf(MAGENTA "THIS PROGRAM IS NOT DESIGNED AS A TESTING TOOL FOR END USERS!\n");
@@ -141,7 +147,7 @@ wait_for_card_again:
 	{
 		printf("Testing SCardGetStatusChange \n");
 		printf("Please insert a working reader\t: ");
-		fflush(stdout);
+		(void)fflush(stdout);
 		rgReaderStates[0].szReader = "\\\\?PnP?\\Notification";
 		rgReaderStates[0].dwCurrentState = SCARD_STATE_EMPTY;
 
@@ -181,8 +187,8 @@ wait_for_card_again:
 			char input[80];
 
 			printf("Enter the reader number\t\t: ");
-			fgets(input, sizeof(input), stdin);
-			sscanf(input, "%d", &iReader);
+			(void)fgets(input, sizeof(input), stdin);
+			(void)sscanf(input, "%d", &iReader);
 
 			if (iReader > p || iReader <= 0)
 				printf("Invalid Value - try again\n");
@@ -195,7 +201,7 @@ wait_for_card_again:
 	rgReaderStates[0].dwCurrentState = SCARD_STATE_EMPTY;
 
 	printf("Waiting for card insertion\t: ");
-	fflush(stdout);
+	(void)fflush(stdout);
 	rv = SCardGetStatusChange(hContext, INFINITE, rgReaderStates, 1);
 	test_rv(rv, hContext, PANIC);
 	if (rgReaderStates[0].dwEventState & SCARD_STATE_UNKNOWN)
@@ -304,31 +310,31 @@ wait_for_card_again:
 
 	printf("Testing SCardGetAttrib\t\t: ");
 	dwBufLen = sizeof(buf);
-	rv = SCardGetAttrib(hCard, SCARD_ATTR_VENDOR_IFD_VERSION, buf, &dwBufLen);
+	rv = SCardGetAttrib(hCard, SCARD_ATTR_VENDOR_IFD_VERSION, buf.as_char, &dwBufLen);
 	test_rv(rv, hContext, DONT_PANIC);
 	if (rv == SCARD_S_SUCCESS)
 		printf("Vendor IFD version\t\t: " GREEN "0x%08lX\n" NORMAL,
-			((DWORD *)buf)[0]);
+			buf.as_DWORD);
 
 	printf("Testing SCardGetAttrib\t\t: ");
 	dwBufLen = sizeof(buf);
-	rv = SCardGetAttrib(hCard, SCARD_ATTR_MAXINPUT, buf, &dwBufLen);
+	rv = SCardGetAttrib(hCard, SCARD_ATTR_MAXINPUT, buf.as_char, &dwBufLen);
 	test_rv(rv, hContext, DONT_PANIC);
 	if (rv == SCARD_S_SUCCESS)
 	{
 		if (dwBufLen == sizeof(uint32_t))
 			printf("Max message length\t\t: " GREEN "%d\n" NORMAL,
-				*(uint32_t *)buf);
+				buf.as_uint32_t);
 		else
 			printf(RED "Wrong size" NORMAL);
 	}
 
 	printf("Testing SCardGetAttrib\t\t: ");
 	dwBufLen = sizeof(buf);
-	rv = SCardGetAttrib(hCard, SCARD_ATTR_VENDOR_NAME, buf, &dwBufLen);
+	rv = SCardGetAttrib(hCard, SCARD_ATTR_VENDOR_NAME, buf.as_char, &dwBufLen);
 	test_rv(rv, hContext, DONT_PANIC);
 	if (rv == SCARD_S_SUCCESS)
-		printf("Vendor name\t\t\t: " GREEN "%s\n" NORMAL, buf);
+		printf("Vendor name\t\t\t: " GREEN "%s\n" NORMAL, buf.as_char);
 
 	printf("Testing SCardSetAttrib\t\t: ");
 	rv = SCardSetAttrib(hCard, SCARD_ATTR_ATR_STRING, (LPCBYTE)"", 1);
@@ -378,12 +384,12 @@ wait_for_card_again:
 
 	if (rv != SCARD_S_SUCCESS)
 	{
-		SCardDisconnect(hCard, SCARD_RESET_CARD);
-		SCardReleaseContext(hContext);
+		(void)SCardDisconnect(hCard, SCARD_RESET_CARD);
+		(void)SCardReleaseContext(hContext);
 	}
 
 	printf("Press enter: ");
-	getchar();
+	(void)getchar();
 	printf("Testing SCardReconnect\t\t: ");
 	rv = SCardReconnect(hCard, SCARD_SHARE_SHARED,
 		SCARD_PROTOCOL_T0 | SCARD_PROTOCOL_T1, SCARD_UNPOWER_CARD, &dwPref);
