@@ -21,7 +21,8 @@ int SendHotplugSignal(void);
 /* defined in winscard_clnt.c */
 LONG SCardCheckDaemonAvailability(void);
 
-int StatSynchronize(struct pubReaderStatesList *readerState);
+int StatSynchronize(/*@null@*/ struct pubReaderStatesList *readerState);
+int StatSynchronizeContext(SCARDCONTEXT hContext);
 
 int CheckForOpenCT(void);
 
